==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/Q4ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q4ExpressionDescription } from "./Q4ExpressionDescription";
/**
 * @hidden
 */
export let Q4ExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class Q4ExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (Q4ExpressionDescriptionMetadata.a == null) {
                Q4ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Q4ExpressionDescriptionMetadata.c(Q4ExpressionDescriptionMetadata.a);
            }
            if (a.k(Q4ExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(Q4ExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            Q4ExpressionDescriptionMetadata.b(a);
            a.ad("Q4Expression", () => new Q4ExpressionDescription());
            a.ac("Q4Expression", Q4ExpressionDescriptionMetadata.a);
        }
    }
    Q4ExpressionDescriptionMetadata.$t = markType(Q4ExpressionDescriptionMetadata, 'Q4ExpressionDescriptionMetadata');
    Q4ExpressionDescriptionMetadata.a = null;
    return Q4ExpressionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/Q4ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q4ExpressionDescription } from "./Q4ExpressionDescription";
/**
 * @hidden
 */
export let Q4ExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class Q4ExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (Q4ExpressionDescriptionMetadata.a == null) {
                Q4ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Q4ExpressionDescriptionMetadata.c(Q4ExpressionDescriptionMetadata.a);
            }
            if (a.k(Q4ExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(Q4ExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            Q4ExpressionDescriptionMetadata.b(a);
            a.ae("Q4Expression", () => new Q4ExpressionDescription());
            a.ad("Q4Expression", Q4ExpressionDescriptionMetadata.a);
        }
    }
    Q4ExpressionDescriptionMetadata.$t = markType(Q4ExpressionDescriptionMetadata, 'Q4ExpressionDescriptionMetadata');
    Q4ExpressionDescriptionMetadata.a = null;
    return Q4ExpressionDescriptionMetadata;
})();
